@@ -5,7 +5,6 @@ import itertools
 import dask.array as da
 import numpy as np
 import pytest
-from astropy import units as u
 from astropy.io import fits
 from astropy.utils.data import get_pkg_data_filename
 from astropy.wcs import WCS
@@ -19,6 +18,13 @@ from reproject.tests.helpers import array_footprint_to_hdulist
 # TODO: add reference comparisons
 
 
+@pytest.fixture(
+    params=[None, "memmap", "none"],
+)
+def dask_method(request):
+    return request.param
+
+
 def as_high_level_wcs(wcs):
     return HighLevelWCSWrapper(SlicedLowLevelWCS(wcs, Ellipsis))
 
@@ -521,47 +527,15 @@ def test_reproject_with_output_array(roundtrip_coords):
 
 
 @pytest.mark.array_compare(single_reference=True)
-@pytest.mark.parametrize("file_format", ["fits", "asdf"])
 @pytest.mark.remote_data
-def test_reproject_roundtrip(file_format):
+def test_reproject_roundtrip(aia_test_data):
     # Test the reprojection with solar data, which ensures that the masking of
     # pixels based on round-tripping works correctly. Using asdf is not just
     # about testing a different format but making sure that GWCS works.
 
-    # The observer handling changed in 2.1.
-    pytest.importorskip("sunpy", minversion="2.1.0")
-    from sunpy.coordinates.ephemeris import get_body_heliographic_stonyhurst
-    from sunpy.map import Map
+    pytest.importorskip("sunpy", minversion="6.0.1")
 
-    if file_format == "fits":
-        map_aia = Map(get_pkg_data_filename("data/aia_171_level1.fits", package="reproject.tests"))
-        data = map_aia.data
-        wcs = map_aia.wcs
-        date = map_aia.date
-        target_wcs = wcs.deepcopy()
-    elif file_format == "asdf":
-        pytest.importorskip("astropy", minversion="4.0")
-        pytest.importorskip("gwcs", minversion="0.12")
-        asdf = pytest.importorskip("asdf")
-        aia = asdf.open(
-            get_pkg_data_filename("data/aia_171_level1.asdf", package="reproject.tests")
-        )
-        data = aia["data"][...]
-        wcs = aia["wcs"]
-        date = wcs.output_frame.reference_frame.obstime
-        target_wcs = Map(
-            get_pkg_data_filename("data/aia_171_level1.fits", package="reproject.tests")
-        ).wcs.deepcopy()
-    else:
-        raise ValueError("file_format should be fits or asdf")
-
-    # Reproject to an observer on Venus
-    target_wcs.wcs.cdelt = ([24, 24] * u.arcsec).to(u.deg)
-    target_wcs.wcs.crpix = [64, 64]
-    venus = get_body_heliographic_stonyhurst("venus", date)
-    target_wcs.wcs.aux.hgln_obs = venus.lon.to_value(u.deg)
-    target_wcs.wcs.aux.hglt_obs = venus.lat.to_value(u.deg)
-    target_wcs.wcs.aux.dsun_obs = venus.radius.to_value(u.m)
+    data, wcs, target_wcs = aia_test_data
 
     output, footprint = reproject_interp((data, wcs), target_wcs, (128, 128))
 
@@ -578,31 +552,20 @@ def test_reproject_roundtrip(file_format):
     return array_footprint_to_hdulist(output, footprint, header_out)
 
 
-def test_reproject_roundtrip_kwarg():
+def test_reproject_roundtrip_kwarg(aia_test_data):
     # Make sure that the roundtrip_coords keyword argument has an effect. This
     # is a regression test for a bug that caused the keyword argument to be
     # ignored when in parallel/blocked mode.
 
-    pytest.importorskip("sunpy", minversion="2.1.0")
-    from sunpy.coordinates.ephemeris import get_body_heliographic_stonyhurst
-    from sunpy.map import Map
+    pytest.importorskip("sunpy", minversion="6.0.1")
 
-    map_aia = Map(get_pkg_data_filename("data/aia_171_level1.fits", package="reproject.tests"))
-
-    # Reproject to an observer on Venus
-    target_wcs = map_aia.wcs.deepcopy()
-    target_wcs.wcs.cdelt = ([24, 24] * u.arcsec).to(u.deg)
-    target_wcs.wcs.crpix = [64, 64]
-    venus = get_body_heliographic_stonyhurst("venus", map_aia.date)
-    target_wcs.wcs.aux.hgln_obs = venus.lon.to_value(u.deg)
-    target_wcs.wcs.aux.hglt_obs = venus.lat.to_value(u.deg)
-    target_wcs.wcs.aux.dsun_obs = venus.radius.to_value(u.m)
+    data, wcs, target_wcs = aia_test_data
 
     output_roundtrip_1 = reproject_interp(
-        map_aia, target_wcs, shape_out=(128, 128), return_footprint=False, roundtrip_coords=True
+        (data, wcs), target_wcs, shape_out=(128, 128), return_footprint=False, roundtrip_coords=True
     )
     output_roundtrip_2 = reproject_interp(
-        map_aia,
+        (data, wcs),
         target_wcs,
         shape_out=(128, 128),
         return_footprint=False,
@@ -613,10 +576,14 @@ def test_reproject_roundtrip_kwarg():
     assert_allclose(output_roundtrip_1, output_roundtrip_2)
 
     output_noroundtrip_1 = reproject_interp(
-        map_aia, target_wcs, shape_out=(128, 128), return_footprint=False, roundtrip_coords=False
+        (data, wcs),
+        target_wcs,
+        shape_out=(128, 128),
+        return_footprint=False,
+        roundtrip_coords=False,
     )
     output_noroundtrip_2 = reproject_interp(
-        map_aia,
+        (data, wcs),
         target_wcs,
         shape_out=(128, 128),
         return_footprint=False,
@@ -928,7 +895,7 @@ def test_reproject_block_size_broadcasting():
 
     # But it should fail if we specify a block size that is smaller that the total array shape
 
-    with pytest.raises(ValueError, match="block shape for extra broadcasted dimensions"):
+    with pytest.raises(ValueError, match="block shape should either match output data shape"):
         reproject_interp(
             (array_in, wcs_in),
             wcs_out,
@@ -939,11 +906,11 @@ def test_reproject_block_size_broadcasting():
         )
 
 
-def test_reproject_dask_return_type():
+def test_reproject_dask_return_type(dask_method):
     # Regression test for a bug that caused dask arrays to not be computable
     # when using return_type='dask' when the input was a dask array.
 
-    array_in = da.ones((350, 250, 150))
+    array_in = da.ones((35, 250, 150))
     wcs_in = WCS(naxis=2)
     wcs_out = WCS(naxis=2)
 
@@ -953,6 +920,7 @@ def test_reproject_dask_return_type():
         shape_out=(300, 300),
         return_type="numpy",
         return_footprint=False,
+        dask_method=dask_method,
     )
 
     result_dask = reproject_interp(
@@ -962,12 +930,13 @@ def test_reproject_dask_return_type():
         block_size=(100, 100),
         return_type="dask",
         return_footprint=False,
+        dask_method=dask_method,
     )
 
     assert_allclose(result_numpy, result_dask.compute(scheduler="synchronous"))
 
 
-def test_auto_block_size():
+def test_auto_block_size(dask_method):
     # Unit test to make sure that specifying block_size='auto' works
 
     array_in = da.ones((350, 250, 150))
@@ -981,6 +950,7 @@ def test_auto_block_size():
             wcs_out,
             shape_out=(300, 300),
             return_type="dask",
+            dask_method=dask_method,
         )
 
     array_out, footprint_out = reproject_interp(
@@ -989,7 +959,103 @@ def test_auto_block_size():
         shape_out=(300, 300),
         return_type="dask",
         block_size="auto",
+        dask_method=dask_method,
     )
 
     assert array_out.chunksize[0] == 350
     assert footprint_out.chunksize[0] == 350
+
+
+@pytest.mark.parametrize("itemsize", (4, 8))
+def test_bigendian_dask(itemsize, dask_method):
+
+    # Regression test for an endianness issue that occurred when the input was
+    # passed in as (dask_array, wcs) and the dask array was big endian.
+
+    array_in_le = da.ones((35, 250, 150), dtype=f">f{itemsize}")
+    array_in_be = da.ones((35, 250, 150), dtype=f"<f{itemsize}")
+    wcs_in = WCS(naxis=2)
+    wcs_out = WCS(naxis=2)
+
+    array_out_be, _ = reproject_interp(
+        (array_in_be, wcs_in),
+        wcs_out,
+        shape_out=(300, 300),
+        block_size=(100, 100),
+        dask_method=dask_method,
+    )
+
+    array_out_le, _ = reproject_interp(
+        (array_in_le, wcs_in),
+        wcs_out,
+        shape_out=(300, 300),
+        block_size=(100, 100),
+        dask_method=dask_method,
+    )
+
+    assert_allclose(array_out_be, array_out_le)
+
+
+def test_reproject_parallel_broadcasting(caplog, dask_method):
+
+    # Unit test for reprojecting using parallelization along broadcasted
+    # dimensions
+
+    array_in = np.ones((350, 250, 150))
+    wcs_in = WCS(naxis=2)
+    wcs_out = WCS(naxis=2)
+
+    # By default if we give a block size that is only in the WCS dimensions,
+    # the data has a single chunk in the broadcasted dimensions
+
+    array1 = reproject_interp(
+        (array_in, wcs_in),
+        wcs_out,
+        shape_out=(300, 300),
+        parallel=1,
+        return_footprint=False,
+        block_size=(100, 100),
+        return_type="dask",
+        dask_method=dask_method,
+    )
+
+    assert array1.chunksize == (350, 100, 100)
+
+    assert "Broadcasting is being used" in caplog.text
+    assert "Not parallelizing along broadcasted dimension" in caplog.text
+    caplog.clear()
+
+    # However, we can also have one chunk in the WCS dimensions and several in
+    # the broadcasted dimensions.
+
+    array2 = reproject_interp(
+        (array_in, wcs_in),
+        wcs_out,
+        shape_out=(300, 300),
+        parallel=1,
+        return_footprint=False,
+        block_size=(1, 300, 300),
+        return_type="dask",
+        dask_method=dask_method,
+    )
+
+    assert array2.chunksize == (1, 300, 300)
+
+    assert "Broadcasting is being used" in caplog.text
+    assert "Parallelizing along broadcasted dimension" in caplog.text
+    caplog.clear()
+
+    # However, we can also have one chunk in the WCS dimensions and several in
+    # the broadcasted dimensions.
+
+    with pytest.raises(ValueError, match="block shape should either match output"):
+        reproject_interp(
+            (array_in, wcs_in),
+            wcs_out,
+            shape_out=(300, 300),
+            parallel=1,
+            return_footprint=False,
+            block_size=(1, 100, 100),
+            return_type="dask",
+            dask_method=dask_method,
+        )
